Learn R Programming

hdbinseg (version 1.0.2)

dcbs.branch: Growing a branch for DCBS algorithm

Description

Grow a branch of the binary tree for the Double CUSUM Binary Segmentation without thresholding

Usage

dcbs.branch(input, phi, s, e, trim)

Value

a vector containing the information about the branch, including the location of the estimated change point and the corresponding test statistic

Arguments

input

input data matrix, with each row representing the component time series or their transformation

phi, trim

see dcbs.alg

s, e

start and end of the interval of consideration at a given iteration