Learn R Programming

hdbinseg (version 1.0.2)

get.gg: Data-driven selection of the average block size

Description

Computes quantities required for data-driven selection of the average block size for stationary bootstrap

Usage

get.gg(z, M = NULL, C = 2, max.K = 5)

Value

Estimates for the two quantities required for average block size selection.

Arguments

z

univariate time series

M

bandwidth, by default, M = NULL to be automatically selected as in Politis and White (2004)

C

C = 2 is the default value chosen for automatic bandwidth selection in Politis and White (2004)

max.K

max.K = 5 is the default value chosen for automatic bandwidth selection in Politis and White (2004)

References

D. N. Politis and H. White (2004) Automatic block-length selection for the dependent bootstrap. Econometric Reviews, vol. 23, pp. 53--70.