Generate thresholds for SBS algorithm via bootstrapping
sbs.thr(
z,
interval = c(1, dim(z)[2]),
cp.type = 1,
do.clean.cp = TRUE,
scales = NULL,
diag = FALSE,
sgn = NULL,
B = 1000,
q = 0.01,
do.parallel = 4
)if cp.type = 1, a vector of length nrow(z), each containing the threshold applied to the CUSUM statistics from the corresponding coordinate of z
if cp.type = 2, a vector of length length(scales)*nrow(z) (when diag = TRUE) or length(scales)*nrow(z)*(nrow(z)+1)/2 (when diag = FALSE), each containing the threshold applied to the CUSUM statistics of the corresponding wavelet transformation of z
input data matrix, with each row representing the component time series
a vector of two containing the start and the end points of the interval from which the bootstrap test statistics are to be calculated
see sbs.alg
if do.clean.cp = TRUE pre-change-point cleaning is performed
if diag = FALSE, wavelet transformations of the cross-covariances are computed with the matching signs