Grow a branch of the binary tree for the Double CUSUM Binary Segmentation without thresholding
dcbs.branch(input, phi, s, e, trim)a vector containing the information about the branch, including the location of the estimated change point and the corresponding test statistic
input data matrix, with each row representing the component time series or their transformation
see dcbs.alg
start and end of the interval of consideration at a given iteration