Computes quantities required for data-driven selection of the average block size for stationary bootstrap
get.gg(z, M = NULL, C = 2, max.K = 5)Estimates for the two quantities required for average block size selection.
univariate time series
bandwidth, by default, M = NULL to be automatically selected as in Politis and White (2004)
C = 2 is the default value chosen for automatic bandwidth selection in Politis and White (2004)
max.K = 5 is the default value chosen for automatic bandwidth selection in Politis and White (2004)
D. N. Politis and H. White (2004) Automatic block-length selection for the dependent bootstrap. Econometric Reviews, vol. 23, pp. 53--70.